#########################################################################
##					        		       ##
##				INPUT FILE FOR PFIM 3.0            ##
#########################################################################


#Name of the project
#-------------------- 

project<-"Doc_example1.2.1"


#Name of the file containing the PK or PD model
#----------------------------------------------

file.model<-"model.r";


#Name of the output file for the results
#---------------------------------------

output<-"Stdout.r";

#RUN:  Evaluation (EVAL) or Optimisation (OPT) 
#-------------------------------------------------------
run<-"EVAL"

#Number of responses
#--------------------------------------------------------------------

nr<-2

#Name of the fixed effects parameters
#-------------------------------------

parameters<-c('Ka','Cl','V','Clm','R')

#Fixed effects parameters values
#--------------------------------

beta<-c(2.8,160,300,0.16,0.003)

#Diagonal Matrix of variance for the random effects:
#---------------------------------------------------

omega<-diag(c(0,0.03,0,0.17,0));


#Standard deviation of the residual error (sig.inter+sig.slope*f)^2:
#------------------------------------------------------------------

sig.interA<-0.000239
sig.slopeA<-0.276

sig.interB<-0
sig.slopeB<-0.135

#Between-subject variance model (1) = additive  (2) = exponential 
#------------------------------------------------------------------

Trand<-2;

#List of the vectors of sampling times for each elementary design 
#you can specify any sampling times for a group by writing NULL 
#ONLY if you have several responses
#-----------------------------------------------------------------

protA<-list(c(1,3,6,12))
protB<-list(c(1,6,11,12))

#Vector of initial proportions or numbers of subjects for each elementary design 
#--------------------------------------------------------------
subjects<-c(50)

#Subjects input: (1) for number of subjects (2) for proportions of subjects
#---------------------------------------------------------------------------
subjects.input<-2

#If 'proportions of subjects' give the total number of samples
#-------------------------------------------------------------
Ntot<-250

################### MODEL OPTION ###########################

#Model form: Differential equations (DE) or analytical form (AF)
#---------------------------------------------------------------

modelform<-"AF"

###### ANALYTICAL MODEL OPTION #############################
############################################################

#Identical dose in each elementary design (Yes=T, No=F)
#-------------------------------------------------------------
dose.identical<-T

# If 'Yes', enter the value of the dose, 
# else, enter the vector of the dose values for each elementary design
#--------------------------------------------------------------------
dose<-c(300)

#Vector of the time intervals of each expression  
#-----------------------------------------------------------
boundA<-list(c(0,Inf))
boundB<-list(c(0,Inf))

###### END ANALYTICAL MODEL OPTION ########################




###### DIFFERENTIAL EQUATION OPTION ##################################
######################################################################

#Initial time for which initial conditions are given
#---------------------------------------------------

#time.condinit<-0

#Identical initial conditions in each elementary design (Yes=T, No=F)
#-------------------------------------------------------------
#condinit.identical<-T

# If 'Yes', enter once the expression of the initial values of the system at the initial time
# else, enter the vectors of the initial conditions for each elementary design
# If initial values depend on parameters to be estimated, 
# enter this parameter into the expression without any quotation marks 
#---------------------------------------------------------

#condinit<-expression(c(0,100))


# Error tolerance for solving differential equations
#----------------------------------------------------

RtolEQ<-1e-08
AtolEQ<-1e-08
Hmax<-Inf # Default value 
#Hmax<-Inf #<1.5/24
###### END DIFFERENTIAL EQUATION OPTION #################################



############ONLY FOR OPTIMISATION ###############################

#Identical sampling times for each response
# (only if you do not have sampling times==NULL)
#-------------------------------------------------------------------------------------
#identical.times<-F

######## OPTIMISATION ALGORITHM OPTION ###############

#Character string for thoice of the optimisation algorithm: 
#	"FW" for the Fedorov-Wynn algorithm 
#	"SIMP" for the Simplex algorithm
#------------------------------------------

#algo.option<-"FW"


########################
#SIMPLEX SPECIFICATION #
########################

#Optimisation of the proportions of subjects: (Yes=T, No=F)
#--------------------------------------------------------------

#subjects.opt<-T

#Vector of lower and upper admissible sampling times
#---------------------------------------------------


#lowerA<-c(0) 
#upperA<-c(24)

#lowerB<-c(0)
#upperB<-c(24)

#Minimum delay between two sampling times
#-------------------------------------------

#delta.time<-0

#Print iteration step (Yes=T, No=F)
#---------------------------------

#iter.print<-T


#Parameter for initial simplex building (%)
#------------------------------------------

#simplex.parameter<-20


#Maximum iteration number
#------------------------

#Max.iter<-5000


#Relative convergence tolerance
#------------------------------ 
#Rctol<-1e-6



#############################
#FEDOROV-WYNN SPECIFICATION #
#############################


#Number of sampling windows
#--------------------------
#nwindA<-1
#nwindB<-1

#List of vector of the allowed sampling times for each sampling window
#--------------------------------------------------------------------

#sampwinA<-list(c(0.166,1,2,3,6,9,12,20)) 
#sampwinB<-list(c(0.166,1,2,3,6,9,12,20,36))


#List of vector of allowed number of points to be taken from each sampling window
#------------------------------------------------------------------------------

#nsampA<-list(c(4))
#nsampB<-list(c(4))

#Maximum total number of sampling times per subject
#--------------------------------------------------

#nmaxptsA<-4
#nmaxptsB<-4

#Minimum total number of sampling times per subject
#--------------------------------------------------

#nminptsA<-4
#nminptsB<-4
############# END OF OPTIMISATION ALGORITHM OPTION ###############






############## GRAPH SPECIFICATION OPTION ###############

#graphical representation (Yes=T, No=F)
#-------------------------------------

graph.logical<-T

#Names on Y axes for each response
#---------------------------------
names.data<-c("Drug Concentration","Metabolite concentration")

#Controls logarithmic axes for the graphical representation.
#Values "xy", "x", or "y" produce log-log or log-x or log-y axes.
#(For standard graphic, log.logical<-F)
#--------------------------------------------------------------

#log.logical<-'y'
log.logical<-F

#Vector of lower and upper sampling times for the graphical representation
#-------------------------------------------------------------------------

graph.infA<-c(0)
graph.supA<-c(24)
graph.infB<-c(0)
graph.supB<-c(24)

#Vector of lower and upper concentration for the graphical representation
#------------------------------------------------------------------------
y.range<-NULL # default range
#y.range<-c(0,10)

############# END OF GRAPH SPECIFICATION OPTION ###############













