#PFIM 3.0 Multiple responses
#Avril 2008
#Copyright  PFIM 3.0  Caroline Bazzoli, Sylvie Retout, Emmanuelle Comets, France Mentr - Universit Paris Diderot  INSERM.
#-----------------------------------------------------------------------------------

#1 compartment bolus model
##########################

#	dose: value of the dose 
# 	N: Number of doses
#	tau: interval between two doses

############################################# Program #######################################
#$Model definition
#$V,k
#$
bolus_1cpt_Vk<-function()
{
	form1<-paste("dose/V*(exp(-k*t))")
	form1<-parse(text=form1)
	tf<-Inf
	return(list(c(form1),tf))
}

#$Model definition
#$V,Cl
#$
bolus_1cpt_VCl<-function()
{
	form1<-paste("dose/V*(exp(-Cl/V*t))")
	form1<-parse(text=form1)
	tf<-Inf
	return(list(c(form1),tf))
}

#Model after N doses with a tau interval
########################################

#$Model definition
#$V,k
#$N,tau
bolus_1cpt_Vk_md<-function(N,tau)
{
	form1N<-paste("dose/(V)*(1-exp(-",N,"*k*",tau,"))/(1-exp(-k*",tau,"))*(exp(-k*(t-(",N,"-1)*",tau,")))")
	form1N<-parse(text=form1N)
	tf<-Inf
	return(list(c(form1N),tf))
}

#$Model definition
#$V,Cl
#$N,tau
bolus_1cpt_VCl_md<-function(N,tau)
{
	form1N<-paste("dose/(V)*(1-exp(-",N,"*Cl/V*",tau,"))/(1-exp(-Cl/V*",tau,"))*(exp(-Cl/V*(t-(",N,"-1)*",tau,")))")
	form1N<-parse(text=form1N)
	tf<-Inf
	return(list(c(form1N),tf))
}

#Model at Steady State for doses given with a tau interval. 
############################################################

#$Model definition
#$V,k
#$tau
bolus_1cpt_Vk_ss<-function(tau,TimeSS=0)
{
	formSS<-paste("dose/(V)/(1-exp(-k*",tau,"))*(exp(-k*(t-(",TimeSS,"))))")
	formSS<-parse(text=formSS)	
	tf<-Inf
	return(list(c(formSS),tf))
}

#$Model definition
#$V,Cl
#$tau
bolus_1cpt_VCl_ss<-function(tau,TimeSS=0)
{
	formSS<-paste("dose/(V)/(1-exp(-Cl/V*",tau,"))*(exp(-Cl/V*(t-(",TimeSS,"))))")
	formSS<-parse(text=formSS)	
	tf<-Inf
	return(list(c(formSS),tf))
}
################################################### END PROGRAM ################################################

#1 compartment first order oral absorption
#######################################

# 	N: Number of doses
#	tau: interval between two doses
############################################# Program #######################################

# Model after 1 dose
#------------------- 

#$Model definition                                                                                  
#$ka,V,k
#$
oral1_1cpt_kaVk<-function()
{
  form1<-paste("dose/V*ka/(ka-k)*(exp(-k*t)-exp(-ka*t))")
  form1<-parse(text=form1,n=-1)
  tf<-Inf
	return(list(c(form1),tf))
}

#$Model definition
#$ka,V,Cl
#$
oral1_1cpt_kaVCl<-function()
{
  form1<-paste("dose/V*ka/(ka-(Cl/V))*(exp(-(Cl/V)*t)-exp(-ka*t))")
  form1<-parse(text=form1,n=-1)
  tf<-Inf
	return(list(c(form1),tf))
}


# Model after the Nst dose (repeated doses) with a tau interval
#--------------------------------------------------------------

#$Model definition
#$ka,V,k
#$N,tau 
oral1_1cpt_kaVk_md<-function(N,tau)
{
  formN<-paste("dose/V*ka/(ka-k)*(exp(-k*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*k*",tau,"))/(1-exp(-k*",tau,"))-exp(-ka*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*ka*",tau,"))/(1-exp(-ka*",tau,")))")
  formN<-parse(text=formN,n=-1)
  tf<-Inf
	return(list(c(formN),tf))
}

#$Model definition
#$ka,V,Cl
#$N,tau 
oral1_1cpt_kaVCl_md<-function(N,tau)
{
  formN<-paste("dose/V*ka/(ka-Cl/V)*(exp(-Cl/V*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*(Cl/V)*",tau,"))/(1-exp(-(Cl/V)*",tau,"))-exp(-ka*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*ka*",tau,"))/(1-exp(-ka*",tau,")))")
  formN<-parse(text=formN,n=-1)
  tf<-Inf
	return(list(c(formN),tf))
}


# Model at Steady State 
#------------------------

#$Model definition
#$ka,V,k
#$tau
oral1_1cpt_kaVk_ss<-function(tau,TimeSS=0)
{
  formSS<-paste("dose/V*ka/(ka-k)*(exp(-k*(t-",TimeSS,"))/(1-exp(-k*",tau,"))-exp(-ka*(t-",TimeSS,"))/(1-exp(-ka*",tau,")))")
  formSS<-parse(text=formSS,n=-1)
  tf<-Inf
	return(list(c(formSS),tf))
}


#$Model definition
#$ka,V,Cl
#$tau
oral1_1cpt_kaVCl_ss<-function(tau,TimeSS=0)
{
  formSS<-paste("dose/V*ka/(ka-(Cl/V))*(exp(-(Cl/V)*(t-",TimeSS,"))/(1-exp(-(Cl/V)*",tau,"))-exp(-ka*(t-",TimeSS,"))/(1-exp(-ka*",tau,")))")
  formSS<-parse(text=formSS,n=-1)
  tf<-Inf
	return(list(c(formSS),tf))
}

################################################### END PROGRAM ################################################   
#1 compartment infusion model
##########################

#	R: Rate of the infusion 
#	TInf: Duration of the infusion
# 	N: Number of doses
#	tau: interval between two doses        
############################################# Program #######################################
#Model after 1 dose
##################

#$Model definition
#$V,k
#$TInf
infusion_1cpt_Vk<-function(TInf)
{
	R<-dose/TInf
  form1<-paste(R,"/(k*V)*(1-exp(-k*",TInf,"))*(exp(-k*(t-",TInf,")))")
	form1<-paste(R,"/(k*V)*(1-exp(-k*t))")
	form1<-parse(text=form1)
	form2<-paste(R,"/(k*V)*(1-exp(-k*",TInf,"))*(exp(-k*(t-",TInf,")))")
	form2<-parse(text=form2)
	tf<-c(TInf,Inf)
	return(list(c(form1,form2),tf))
}

#$Model definition
#$V,Cl
#$TInf
infusion_1cpt_VCl<-function(TInf)
{
	R<-dose/TInf
  form1<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*",TInf,"))*(exp(-(Cl/V)*(t-",TInf,")))")
	form1<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*t))")
	form1<-parse(text=form1)
	form2<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*",TInf,"))*(exp(-(Cl/V)*(t-",TInf,")))")
	form2<-parse(text=form2)
	tf<-c(TInf,Inf)
	return(list(c(form1,form2),tf))
}
             
#Model after N doses with a tau interval
########################################

#Needed intermediate function
#____________________________

infusion_1cpt_Ninter_Vk<-function(TInf,N,tau,t)
{
	R<-dose/TInf
  formN<-paste(R,"/(k*V)*(1-exp(-k*",TInf,"))*(1-exp(-",N,"*k*",tau,"))/(1-exp(-k*",tau,"))*(exp(-k*(t-(",N,"-1)*",tau,"-",TInf,")))")
	return(formN)
}

#___________________________
#$Model definition
#$V,k
#$TInf,N,tau
infusion_1cpt_Vk_md<-function(TInf,N,tau)
{
	R<-dose/TInf	
	form1N<-paste(R,"/(k*V)*(1-exp(-k*(t-(",N,"-1)*",tau,")))+",infusion_1cpt_Ninter_Vk(TInf,N-1,tau,((N-1)*tau)))
	form2N<-infusion_1cpt_Ninter_Vk(TInf,N,tau,t)
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)	
	tf<-c(TInf,Inf)
	return(list(c(form1N,form2N),tf))
}

#Needed intermediate function
#____________________________

infusion_1cpt_Ninter_VCl<-function(TInf,N,tau,t)
{
  R<-dose/TInf
	formN<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*",TInf,"))*(1-exp(-",N,"*(Cl/V)*",tau,"))/(1-exp(-(Cl/V)*",tau,"))*(exp(-(Cl/V)*(t-(",N,"-1)*",tau,"-",TInf,")))")
	return(formN)
}

#___________________________

#$Model definition
#$V,Cl
#$TInf,N,tau
infusion_1cpt_VCl_md<-function(TInf,N,tau)
{
	R<-dose/TInf	
	form1N<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*(t-(",N,"-1)*",tau,")))+",infusion_1cpt_Ninter_VCl(TInf,N-1,tau,((N-1)*tau)))
	form2N<-infusion_1cpt_Ninter_VCl(TInf,N,tau,t)
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)	
	tf<-c(TInf,Inf)
	return(list(c(form1N,form2N),tf))
}

#Model at Steady State for doses given with a tau interval. 
############################################################

#$Model definition
#$V,k
#$TInf,tau
infusion_1cpt_Vk_ss<-function(TInf,tau,TimeSS=0)
{
  R<-dose/TInf
  form1SS<-paste(R,"/(k*V)*((1-exp(-k*(t-",TimeSS,")))+exp(-k*",tau,")*(1-exp(-k*",TInf,"))*(exp(-k*(t-",TimeSS,"-",TInf,")))/(1-exp(-k*",tau,")))" )
  form2SS<-paste(R,"/(k*V)*(1-exp(-k*",TInf,"))*exp(-k*(t-",TimeSS,"-",TInf,"))/(1-exp(-k*",tau,"))" )
  form1SS<-parse(text=form1SS)
	form2SS<-parse(text=form2SS)	   
  tf<-c(TInf,Inf)
	return(list(c(form1SS,form2SS),tf))
}

#$Model definition
#$V,Cl
#$TInf,tau
infusion_1cpt_VCl_ss<-function(TInf,tau,TimeSS=0)
{
  R<-dose/TInf
  form1SS<-paste(R,"/(Cl)*((1-exp(-(Cl/V)*(t-",TimeSS,")))+exp(-(Cl/V)*",tau,")*(1-exp(-(Cl/V)*",TInf,"))*(exp(-(Cl/V)*(t-",TimeSS,"-",TInf,")))/(1-exp(-(Cl/V)*",tau,")))" )
  form2SS<-paste(R,"/(Cl)*(1-exp(-(Cl/V)*",TInf,"))*exp(-(Cl/V)*(t-",TimeSS,"-",TInf,"))/(1-exp(-(Cl/V)*",tau,"))" )
  form1SS<-parse(text=form1SS)
	form2SS<-parse(text=form2SS)	
	tf<-c(TInf,Inf)
	return(list(c(form1SS,form2SS),tf))

}
################################################### END PROGRAM ################################################

#2 compartments bolus model
##########################

#	dose: value of the dose
# 	N: Number of doses
#	tau: interval between two doses

############################################# Program #######################################


myprefunc<-function(k10,k12,k21,V)
{
  s<-paste("(",k10,"+",k21,"+",k12,")")
  rac2<-paste("sqrt(",s,"^2-4*",k10,"*",k21,")")
  alpha1<-paste("((",s,"+",rac2,")/2)")
  alpha2<-paste("((",s,"-",rac2,")/2)")

  A<-paste("1*(",alpha1,"-",k21,")/(",V,"*(",alpha1,"-",alpha2,"))")
  B<-paste("1*(",k21,"-",alpha2,")/(",V,"*(",alpha1,"-",alpha2,"))")
  return(list(alpha1,alpha2,A,B))
}

#Model after 1 dose
##################

#$Model definition
#$V,k,k12,k21
#$
bolus_2cpt_Vkk12k21<-function()
{
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	form1<-paste("dose*(",A,"*exp(-",alpha1,"*t)+",B,"*exp(-",alpha2,"*t))")
	form1<-parse(text=form1)
	tf<-Inf
	return(list(c(form1),tf))
}

#$Model definition
#$Cl,V1,Q,V2
#$
bolus_2cpt_ClV1QV2<-function()
{
	prevalue<-myprefunc(k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	form1<-paste("dose*(",A,"*exp(-",alpha1,"*t)+",B,"*exp(-",alpha2,"*t))")
	form1<-parse(text=form1)
	tf<-Inf
	return(list(c(form1),tf))
}

#Model after N doses with a tau interval
########################################

#$Model definition
#$V,k,k12,k21
#$N,tau
bolus_2cpt_Vkk12k21_md<-function(N,tau)
{
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("((1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("((1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,")))")
	formN<-paste("dose*(",A,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"))*",multiterm1,"+",B,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))*",multiterm2,")")	
	formN<-parse(text=formN)
	tf<-Inf
	return(list(c(formN),tf))
}

#$Model definition
#$Cl,V1,Q,V2
#$N,tau
bolus_2cpt_ClV1QV2_md<-function(N,tau)
{
	prevalue<-myprefunc(k="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("((1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("((1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,")))")
	formN<-paste("dose*(",A,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"))*",multiterm1,"+",B,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))*",multiterm2,")")
	formN<-parse(text=formN)
	tf<-Inf
	return(list(c(formN),tf))
}
 

#Model at Steady State for doses given with a tau interval. 
###########################################################

#$Model definition
#$V,k,k12,k21
#$tau
bolus_2cpt_Vkk12k21_ss<-function(tau,TimeSS=0)
{
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("(1/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("(1/(1-exp(-",alpha2,"*",tau,")))")
	formSS<-paste("dose*(",A,"*exp(-",alpha1,"*(t-",TimeSS,"))*",multiterm1,"+",B,"*exp(-",alpha2,"*(t-",TimeSS,"))*",multiterm2,")")
	formSS<-parse(text=formSS)	
	tf<-Inf
	return(list(c(formSS),tf))
}

#$Model definition
#$Cl,V1,Q,V2
#$tau
bolus_2cpt_ClV1QV2_ss<-function(tau,TimeSS=0)
{
	prevalue<-myprefunc(k="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("(1/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("(1/(1-exp(-",alpha2,"*",tau,")))")
	formSS<-paste("dose*(",A,"*exp(-",alpha1,"*(t-",TimeSS,"))*",multiterm1,"+",B,"*exp(-",alpha2,"*(t-",TimeSS,"))*",multiterm2,")")
	formSS<-parse(text=formSS)	
	tf<-Inf
	return(list(c(formSS),tf))
}


################################################### END PROGRAM ################################################

#2 compartments first order oral absorption
########################################

# 	N: Number of doses
#	tau: interval between two doses

###################################################################################################

myprefuncoral<-function(ka,k10,k12,k21,V)
{
  s<-paste("(",k10,"+",k21,"+",k12,")")
  rac2<-paste("sqrt(",s,"^2-4*",k10,"*",k21,")")
  alpha1<-paste("((",s,"+",rac2,")/2)")
  alpha2<-paste("((",s,"-",rac2,")/2)")

  A<-paste("dose*",ka,"/",V,"*(",k21,"-",ka,")/((",alpha1,"-",ka,")*(",alpha2,"-",ka,"))")
  B<-paste("dose*",ka,"/",V,"*(",k21,"-",alpha1,")/((",ka,"-",alpha1,")*(",alpha2,"-",alpha1,"))")
  C<-paste("dose*",ka,"/",V,"*(",k21,"-",alpha2,")/((",ka,"-",alpha2,")*(",alpha1,"-",alpha2,"))")      
  return(list(alpha1,alpha2,A,B,C))
}

# Model after 1 dose
#-------------------                                                                                   

#$Model definition
#$ka,V,k,k12,k21
#$
oral1_2cpt_kaVkk12k21<-function()
{
	prevalue<-myprefuncoral(ka="ka",k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]

  form1<-paste(A,"*exp(-ka*t)+",B,"*exp(-",alpha1,"*t)+",C,"*exp(-",alpha2,"*t)")
  form1<-parse(text=form1,n=-1)
 	tf<-Inf
	return(list(c(form1),tf))
}

#$Model definition
#$ka,Cl,V1,Q,V2
#$
oral1_2cpt_kaClV1QV2<-function()
{                                                 
	prevalue<-myprefuncoral(ka="ka",k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]

  form1<-paste(A,"*exp(-ka*t)+",B,"*exp(-",alpha1,"*t)+",C,"*exp(-",alpha2,"*t)")
  form1<-parse(text=form1,n=-1)
 	tf<-Inf
	return(list(c(form1),tf))
}


# Model after the Nst dose (repeated doses) with a tau interval
#--------------------------------------------------------------
#$Model definition
#$ka,V,k,k12,k21
#$N,tau
 oral1_2cpt_kaVkk12k21_md<-function(N,tau)
{
	prevalue<-myprefuncoral(ka="ka",k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	formN<-paste(A,"*exp(-ka*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*ka*",tau,"))/(1-exp(-ka*",tau,"))+",B,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,"))+",C,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,"))")
	formN<-parse(text=formN,n=-1)
	tf<-Inf
	return(list(c(formN),tf))
}

#$Model definition
#$ka,Cl,V1,Q,V2
#$N,tau
oral1_2cpt_kaClV1QV2_md<-function(N,tau)
{
	prevalue<-myprefuncoral(ka="ka",k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	formN<-paste(A,"*exp(-ka*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*ka*",tau,"))/(1-exp(-ka*",tau,"))+",B,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,"))+",C,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))*(1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,"))")
	formN<-parse(text=formN,n=-1)
	tf<-Inf
	return(list(c(formN),tf))
}

# Model at Steady State 
#-----------------------

#$Model definition
#$ka,V,k,k12,k21
#$tau                  
oral1_2cpt_kaVkk12k21_ss<-function(tau,TimeSS=0)
{
	prevalue<-myprefuncoral(ka="ka",k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	formSS<-paste(A,"*exp(-ka*(t-",TimeSS,"))/(1-exp(-ka*",tau,"))+",B,"*exp(-",alpha1,"*(t-",TimeSS,"))/(1-exp(-",alpha1,"*",tau,"))+",C,"*exp(-",alpha2,"*(t-",TimeSS,"))/(1-exp(-",alpha2,"*",tau,"))")
	formSS<-parse(text=formSS,n=-1)
	tf<-Inf
	return(list(c(formSS),tf))
}

#$Model definition
#$ka,Cl,V1,Q,V2
#$tau 
oral1_2cpt_kaClV1QV2_ss<-function(tau,TimeSS=0)
{                                                                    
	prevalue<-myprefuncoral(ka="ka",k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")  
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	C<-prevalue[[5]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	formSS<-paste(A,"*exp(-ka*(t-",TimeSS,"))/(1-exp(-ka*",tau,"))+",B,"*exp(-",alpha1,"*(t-",TimeSS,"))/(1-exp(-",alpha1,"*",tau,"))+",C,"*exp(-",alpha2,"*(t-",TimeSS,"))/(1-exp(-",alpha2,"*",tau,"))")
	formSS<-parse(text=formSS,n=-1)
	tf<-Inf
	return(list(c(formSS),tf))
}

################################################### END PROGRAM ################################################

#2 compartments infusion model
##########################

#	R: Rate of the infusion 
#	TInf: Duration of the infusion
# 	N: Number of doses
#	tau: interval between two doses

#Model after 1 dose
##################


#$Model definition
#$V,k,k12,k21
#$TInf
infusion_2cpt_Vkk12k21<-function(TInf)
{
     R<-dose/TInf
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	form1<-paste(R,"*(",A,"/",alpha1,"*(1-exp(-",alpha1,"*t))+",B,"/",alpha2,"*(1-exp(-",alpha2,"*t)))")
	form1<-parse(text=form1)
	form2<-paste(-R,"*(",A,"/",alpha1,"*(exp(-",alpha1,"*",TInf,")-1)*exp(-",alpha1,"*(t-",TInf,"))+",B,"/",alpha2,"*(exp(-",alpha2,"*",TInf,")-1)*exp(-",alpha2,"*(t-",TInf,")))")
	form2<-parse(text=form2)
	tf<-c(TInf,Inf)
	return(list(c(form1,form2),tf))
}

#$Model definition
#$Cl,V1,Q,V2
#$TInf
infusion_2cpt_ClV1QV2<-function(TInf)
{
  R<-dose/TInf
	prevalue<-myprefunc(k="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")      
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	form1<-paste(R,"*(",A,"/",alpha1,"*(1-exp(-",alpha1,"*t))+",B,"/",alpha2,"*(1-exp(-",alpha2,"*t)))")
	form1<-parse(text=form1)
	form2<-paste(-R,"*(",A,"/",alpha1,"*(exp(-",alpha1,"*",TInf,")-1)*exp(-",alpha1,"*(t-",TInf,"))+",B,"/",alpha2,"*(exp(-",alpha2,"*",TInf,")-1)*exp(-",alpha2,"*(t-",TInf,")))")
	form2<-parse(text=form2)
	tf<-c(TInf,Inf)
	return(list(c(form1,form2),tf))
}


#Model after N doses with a tau interval
########################################

#Needed intermediate function
#____________________________

infusion_2cpt_Ninter_Vkk12k21<-function(TInf,N,tau,t)
{
	R<-dose/TInf
  prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("((1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("((1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,")))")
	formN<-paste(-R,"*(",A,"/",alpha1,"*(exp(-",alpha1,"*",TInf,")-1)*",multiterm1,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"-",TInf,"))+",B,"/",alpha2,"*(exp(-",alpha2,"*",TInf,")-1)*",multiterm2,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"-",TInf,")))")
	return(formN)
}
#___________________________
#$Model definition
#$V,k,k12,k21
#$TInf,N,tau
infusion_2cpt_Vkk12k21_md<-function(TInf,N,tau)
{
  R<-dose/TInf
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]                                                                                                                                
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]	
	form1N<-paste(R,"*(",A,"/",alpha1,"*(1-exp(-",alpha1,"*(t-(",N,"-1)*",tau,")))+",B,"/",alpha2,"*(1-exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))))+",infusion_2cpt_Ninter_Vkk12k21(TInf,N-1,tau,((N-1)*tau)))
	form2N<-infusion_2cpt_Ninter_Vkk12k21(TInf,N,tau,t)
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)
  tf<-c(TInf+(N-1)*tau,Inf)
	return(list(c(form1N,form2N),tf))	
}
#Needed intermediate function
#____________________________
         
infusion_2cpt_Ninter_ClV1QV2<-function(TInf,N,tau,t)
{
	R<-1/TInf
  prevalue<-myprefunc(k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]
	multiterm1<-paste("((1-exp(-",N,"*",alpha1,"*",tau,"))/(1-exp(-",alpha1,"*",tau,")))")
	multiterm2<-paste("((1-exp(-",N,"*",alpha2,"*",tau,"))/(1-exp(-",alpha2,"*",tau,")))")
	formN<-paste(-R,"*(",A,"/",alpha1,"*(exp(-",alpha1,"*",TInf,")-1)*",multiterm1,"*exp(-",alpha1,"*(t-(",N,"-1)*",tau,"-",TInf,"))+",B,"/",alpha2,"*(exp(-",alpha2,"*",TInf,")-1)*",multiterm2,"*exp(-",alpha2,"*(t-(",N,"-1)*",tau,"-",TInf,")))")
	return(formN)
}
#___________________________
#$Model definition                                           
#$Cl,V1,Q,V2
#$TInf,N,tau
infusion_2cpt_ClV1QV2_md<-function(TInf,N,tau)
{
  R<-dose/TInf
	prevalue<-myprefunc(k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]	
	form1N<-paste(R,"*(",A,"/",alpha1,"*(1-exp(-",alpha1,"*(t-(",N,"-1)*",tau,")))+",B,"/",alpha2,"*(1-exp(-",alpha2,"*(t-(",N,"-1)*",tau,"))))+",infusion_2cpt_Ninter_ClV1QV2(TInf,N-1,tau,((N-1)*tau)))

	form2N<-infusion_2cpt_Ninter_ClV1QV2(TInf,N,tau,t)
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)	
	tf<-c(TInf+(N-1)*tau,Inf)
	return(list(c(form1N,form2N),tf))	
}



#Model at Steady State for doses given with a tau interval.
###########################################################
#___________________________
#$Model definition
#$V,k,k12,k21
#$TInf,tau
infusion_2cpt_Vkk12k21_ss<-function(TInf,tau)
{
  R<-dose/TInf
	prevalue<-myprefunc(k10="k",k12="k12",k21="k21",V="V")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]

  form1N<-paste(R,"*(",A,"/",alpha1,"*((1-exp(-",alpha1,"*t))+exp(-",alpha1,"*",tau,")*
          (1-exp(-",alpha1,"*",TInf,"))*exp(-",alpha1,"*(t-",TInf,"))/(1-exp(-",alpha1,"*",tau,")))
          +",B,"/",alpha2,"*((1-exp(-",alpha2,"*t))+exp(-",alpha2,"*",tau,")*(1-exp(-",alpha2,"*",TInf,"))
          *exp(-",alpha2,"*(t-",TInf,"))/(1-exp(-",alpha2,"*",tau,"))))")
  form2N<-paste(R,"*(",A,"/",alpha1,"*((1-exp(-",alpha1,"*",TInf,"))*exp(-",alpha1,"*(t-",TInf,"))/(1-exp(-",alpha1,"*",tau,")))+",B,"/",alpha2,"*((1-exp(-",alpha2,"*",TInf,"))*exp(-",alpha2,"*(t-",TInf,"))/(1-exp(-",alpha2,"*",tau,"))))")
  
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)
  tf<-c(TInf,Inf)
	return(list(c(form1N,form2N),tf))

}

#$Model definition
#$Cl,V1,Q,V2
#$TInf,tau
infusion_2cpt_ClV1QV2_ss<-function(TInf,tau)
{
  R<-dose/TInf                     
	prevalue<-myprefunc(k10="Cl/V1",k12="Q/V1",k21="Q/V2",V="V1")
	A<-prevalue[[3]]
	B<-prevalue[[4]]
	alpha1<-prevalue[[1]]
	alpha2<-prevalue[[2]]

  form1N<-paste(R,"*(",A,"/",alpha1,"*((1-exp(-",alpha1,"*t))+exp(-",alpha1,"*",tau,")*
          (1-exp(-",alpha1,"*",TInf,"))*exp(-",alpha1,"*(t-",TInf,"))/(1-exp(-",alpha1,"*",tau,")))
          +",B,"/",alpha2,"*((1-exp(-",alpha2,"*t))+exp(-",alpha2,"*",tau,")*(1-exp(-",alpha2,"*",TInf,"))
          *exp(-",alpha2,"*(t-",TInf,"))/(1-exp(-",alpha2,"*",tau,"))))")
  form2N<-paste(R,"*(",A,"/",alpha1,"*((1-exp(-",alpha1,"*",TInf,"))*exp(-",alpha1,"*(t-",TInf,"))/(1-exp(-",alpha1,"*",tau,")))+",B,"/",alpha2,"*((1-exp(-",alpha2,"*",TInf,"))*exp(-",alpha2,"*(t-",TInf,"))/(1-exp(-",alpha2,"*",tau,"))))")
  
	form1N<-parse(text=form1N)
	form2N<-parse(text=form2N)
  tf<-c(TInf,Inf)
	return(list(c(form1N,form2N),tf))

}


################################################### END PROGRAM ################################################
